@@ -1,13 +1,14 @@
+use v5.16;
+use strict;
+use warnings;
+use utf8;
+
 package Art::World {
 
-  use v5.16;
-  use utf8;
-
-  our $VERSION = '0.16_04';
+  our $VERSION = '0.16_05';
 
   use Zydeco version => $VERSION, authority => 'cpan:SMONFF';
 
-  class Playground;
 
   role Concept {
     method idea_of_project {}
@@ -16,6 +17,8 @@ package Art::World {
     # etc.
   }
 
+  class Playground;
+
   class Abstraction with Concept {
     has idea!, process, file!, discourse, time, project;
   }
@@ -67,6 +70,11 @@ package Art::World {
     }
   }
 
+  role Underground {
+    method experiment {
+      say "Underground";
+    }
+  }
 
   class Wildlife {
 
@@ -96,6 +104,8 @@ package Art::World {
           say $self->name . ' have shitty idea' if true;
         }
 
+        # factory underground_artist does underground
+
         method has_collectors {
           if ( scalar @{ $self->collectors }  > 1 ) {
             $self->collected( true );
@@ -201,40 +211,51 @@ L<history|Art::World::Manual/"HISTORY"> and the
 L<objectives|Art::World::Manual/"OBJECTIVES"> section could be very handy to
 understand how this is an artwork using programming.
 
-=head1 OBJECTS
+=head1 ROLES
 
-=head2 Art
+=head2 Active
 
-Will be what you decide it to be
+Provide a C<participate> method.
 
-=head2 Wildlife
+=head2 Buyer
 
-Activists of the Art World.
+Provide a C<aquire> method requiring some C<money>. All this behavior and
+attributes are encapsulated in the C<Buyer> role because there is no such thing
+as somebody in the art world that buy but doesn't sale.
 
-  my $agent = Art::World::Wildlife->new_agent( name => $f->person_name );
+=head2 Showable
+
+Only an object that does the C<Showable> role can be exhibited. An object should
+be exhibited only if it reached the C<Showable> stage.
+
+=head2 Collectionable
+
+If it's collectionable, it can go to a C<Collector> collection or in a C<Museum>.
+
+=head1 CLASSES
+
+=head2 Agent
+
+They are the activists of the Art World, well known as the I<wildlife>.
+
+  my $agent = Art::World->new_agent( name => $f->person_name );
 
   $agent->participate;    # ==>  "That's interesting"
 
 A generic entity that can be any activist of the L<Art::World>. Provides all
 kind of C<Agents> classes and roles.
 
-=head3 Roles
+=head2 Art
 
-=over
+Will be what you decide it to be depending on how you combine all the entities.
 
-=item C<Active>
+=head2 Artwork
 
-Provide a C<participate> method.
+The base thing producted by artists. Artwork is subclass of
+L<Art::Work> that have a C<Showable> and C<Collectionable> role.
 
-=item C<Buyer>
 
-Provide a C<aquire> method requiring some C<money>.
-
-=back
-
-=head3 Classes
-
-=head4 C<Artist>
+=head4 Artist
 
 The artist got a lots of wonderful powers:
 
@@ -251,18 +272,27 @@ change in time.
 
 =back
 
-=head2 Artwork
+=head2 Collector
 
-The base thing producted by artists. Artwork is a Zydeco subclass of
-L<Art::Work> that have a Showable and Collectionable role..
+=head2 Gallery
+
+Just another kind of L<C<Place>|Art::World/"Place">, mostly commercial.
+
+Since it implements the L<C<Buyer>|Art::World/"Buyer"> role, a gallery can both
+C<acquire()> and C<sell()>.
+
+=head2 Museum
+
+Yet another kind of C<Place>, an institution with a lot of L<C<Artworks>|Art::World/"Artwork"> in the basement.
 
 =head2 Place
 
-Since it implements the Buyer role, a gallery can both acquire() and sell(). All
-this is encapsulated in the Buyer role because there is no such thing as
-somebody in the art world that buy but doesn't sale.
+=head2 Public
 
-=cut
+=head2 Work
+
+There are not only C<Artworks>. All C<Agent>s produce various kind of work or
+help consuming or implementing C<Art>.
 
 =head1 AUTHOR
 
